/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


/*
  This position event handler handles the position event which
  we requested when we got a mouse click.    If a position
  event comes in when we haven't received a mouse click,
  it is ignored (or passed on to any other mouse-click handlers
  that might be registered).
*/


package rp1demo.clientzero;
import  rp1.rossum.*;
import  rp1.rossum.event.RsEncoderStatusEventHandler;
import  rp1.rossum.event.RsEncoderStatusEvent;
import java.lang.Math;

public class ClnEncoderStatusEventHandler implements RsEncoderStatusEventHandler {

   private ClnMain      client;
   private RsEncoder [] encoders;
   private RsEncoderStatusEvent  [] sEvents;
   private RsWheel   [] wheels;
   private double       trackWidth;

   // constructors -----------------------------------------------
   public ClnEncoderStatusEventHandler(ClnMain client){
      this.client   = client;
      this.encoders = client.encoders;
      this.wheels   = ((RsDifferentialSteering)client.body.wheelSystem).getWheels();
      this.trackWidth = ((RsDifferentialSteering)client.body.wheelSystem).getTrackWidth();

      if(encoders!=null)
          sEvents = new RsEncoderStatusEvent[encoders.length];
   }

   // methods related to interface -------------------------------
   public void process(RsEncoderStatusEvent event){
     if(encoders==null){
        return;
     }

     int       i;
     for(i=0; i<encoders.length; i++){
        if(encoders[i].getID()==event.encoderID){
            sEvents[i] = event;
            break;
        }
     }
     if(i==encoders.length)
        return;  // we didn't find a match (shouldn't happen)


     if(i==encoders.length-1){
        // this is the last in a series of encoder status events
        // and we now have complete information on encoder readings
        double sL, sR, theta, sMean;
        sL = wheels[0].mapAccumulatorToDisplacement(sEvents[0].accumulatorValue);
        sR = wheels[1].mapAccumulatorToDisplacement(sEvents[1].accumulatorValue);
        theta = (sR-sL)/trackWidth;
        sMean = (sR+sL)/2.0;
        if(Math.abs(sMean)>1.0e-6){
           if(Math.abs(theta)<1.0e-6){
              // it appears to have followed a straight-line path
              client.drPoint.x += sMean*Math.cos(client.drTheta);
              client.drPoint.y += sMean*Math.sin(client.drTheta);
            }else{
              client.drPoint.x += (sMean/theta)*(Math.sin(theta+client.drTheta)-Math.sin(client.drTheta) );
              client.drPoint.y -= (sMean/theta)*(Math.cos(theta+client.drTheta)-Math.cos(client.drTheta) );
            }
        }
        client.drTheta+=theta;
        if(client.drTheta>=0)
           client.drTheta = client.drTheta%(2.0*Math.PI);
        else
           client.drTheta = 2.0*Math.PI - ((-client.drTheta)%(2.0*Math.PI));


        client.log("encoder status received\n"+
                   "   accumulaters (l/r): "+sEvents[0].accumulatorValue+", "+sEvents[1].accumulatorValue+"\n"+
                   "   displacements "+sL+", "+sR+"   (mean: "+sMean+")\n"+
                   "   change of orientation (deg): "+Math.toDegrees(theta)+"\n"+
                   "   position (x,y): "+client.drPoint.x+", "+client.drPoint.y+"\n"+
                   "   orientation:    "+Math.toDegrees(client.drTheta));


     }
   }
}

