/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.clientzero;
import  rp1.rossum.event.RsMotionHaltedEventHandler;
import  rp1.rossum.event.RsMotionHaltedEvent;

public class ClnMotionHaltedEventHandler implements RsMotionHaltedEventHandler {

   private ClnMain   client;

   // constructors --------------------------------------------
   public ClnMotionHaltedEventHandler(ClnMain client){
     this.client   = client;
   }

   // methods related to interface ---------------------------
   public void process(RsMotionHaltedEvent event){
      client.verbose("Received motion halted event, cause: "+event.whyHalted());

      client.sendEncoderStatusRequest(client.encoders, true);

      if(!client.autoPilot){
         return;
      }else{
         if(event.causeOfHalt==RsMotionHaltedEvent.HALTED_ON_COLLISION){
            client.log("Search failed -- excusion halted due to collision");
            client.searchRelatedTimeoutIndex=0;
            client.motionPath=null;
            client.motionPathIndex=0;
            return;
         }
         if(client.searchIndex==ClnMain.SEARCH_FOR_TARGET){
            // if search for target is never interrupted by a
            // detection, we will simply follow motion plan all
            // the way back to home.
            if(event.causeOfHalt==RsMotionHaltedEvent.HALTED_ON_COMPLETION){
               if(!client.advanceMotionPath()){
                  client.log("Excursion failed to detect a target");
                  client.scheduleNextExcursion(15.0);
               }
            }
         }else if(client.searchIndex==ClnMain.APPROACH_TARGET){
            // when the approach-target motion-plan completes, we issue
            // a timeout request for 3 seconds to simulate the time it
            // takes to put out a candle.
            if(event.causeOfHalt==RsMotionHaltedEvent.HALTED_ON_COMPLETION){
               if(!client.advanceMotionPath()){
                   // there was no more motion plan left to advance.  it's time
                   // to issue the timeout
                   client.searchRelatedTimeoutIndex = client.sendTimeoutRequest(3.0);
                   client.searchIndex=ClnMain.EXTINGUISH_TARGET;
               }
            }
         }else if(client.searchIndex==ClnMain.RETURN_HOME){
            if(event.causeOfHalt==RsMotionHaltedEvent.HALTED_ON_COMPLETION){
               if(!client.advanceMotionPath()){
                  client.log("Excursion completed");
                  client.scheduleNextExcursion(10.0);
               }
            }
         }
      }
   }
}

