/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.clientzero;
import  rp1.rossum.*;
import  rp1.rossum.event.RsPlacementEventHandler;
import  rp1.rossum.event.RsPlacementEvent;



public class ClnPlacementEventHandler implements RsPlacementEventHandler {

   private ClnMain client;

   public ClnPlacementEventHandler(ClnMain client){
      this.client     = client;
   }

   public void process(RsPlacementEvent event) {
      client.verbose("Received placement at "+event.name);
      client.body.setPlacement(true);
      client.body.setMotion(
         new RsMotionNull(
            event.simTime,
            event.orientation,
            event.x,
            event.y));
      client.drPoint.x = event.x;
      client.drPoint.y = event.y;
      client.drTheta   = event.orientation;

      client.log("robot placement at\n"+
          "   position (x,y): "+client.drPoint.x+", "+client.drPoint.y+"\n"+
          "   orientation:    "+Math.toDegrees(client.drTheta));

      if(client.autoPilot){
         if(client.navNet==null){
            // the information needed to perform an excursion is not yet
            // available, schedule the excusion to occur in another
            // couple of seconds...  by then it should be available
            client.scheduleNextExcursion(2.0);
           return;
        }
        client.sendExclusiveRandomTargetSelectionRequest();
        client.initiateSearch(event.x, event.y, event.orientation);
        client.log("Search initiated with nMove="+client.searchPath.nMove);
      }
   }
}
