/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.demozero;
import  rp1.rossum.*;
import rp1demo.clientzero.*;

import java.io.*;

public class DemoMain implements RsRunnable
{
   ClnMain  client;

   // implement a main to allow this class to serve as an Application -----
   public static void main(String args[]) throws IOException
   {
      DemoMain demo = new DemoMain();
      demo.initialize();   // throws IOException if unable to reach server
      demo.run();
   }


   public DemoMain(){
      client = new ClnMain();
   }


   public void setInputOutputStreams(InputStream input, OutputStream output){
      client.setInputOutputStreams(input, output);
   }

   public void setLogger(RsLogInterface logger){
      client.setLogger(logger);
   }

   public void initialize () throws IOException {

      client.initialize();

      client.log("Initializing Demo Control Panel");

      DemoFrame  demoFrame = new DemoFrame(client);
      demoFrame.setVisible(true);

      client.log("Registering Demo Event Handlers");

      client.setProtocolShutdownHandler(  new DemoProtocolShutdownHandler(demoFrame));

      client.addMotionStartedEventHandler(new DemoMotionStartedEventHandler(demoFrame));
      client.addMotionHaltedEventHandler( new DemoMotionHaltedEventHandler(demoFrame));
      client.addPositionEventHandler(     new DemoPositionEventHandler(demoFrame));
      client.addTimeoutEventHandler(      new DemoTimeoutEventHandler(client));
      client.addPlacementEventHandler(    new DemoPlacementEventHandler(demoFrame));
      client.addTargetSensorEventHandler(
         (RsBodyTargetSensor)(client.getBody().getPartByName("head")),
         new DemoTargetSensorEventHandler(demoFrame));

      client.sendTimeoutRequest(1.0);



   }

   public void run(){
      client.run();
   }
}
