/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */

/*  A note on the Auto-Pilot choice...

   Auto-Pilot mode cannot be enabled until the ClnMain object
   has a valid nav-net (which is created when ClnMain receives
   a floor-plan event).   So we have to defer the addition of
   "Auto-Pilot" to the mode-choice until later.   We provide a
   method checkForAutoPilot() which can be invoked by the
   Demo event handlers at some time in the future.
*/


package rp1demo.demozero;

import java.awt.*;
import java.awt.event.*;

import  rp1.rossum.*;
import  rp1.rossum.event.*;
import rp1demo.clientzero.*;

public class DemoPanel extends Panel
{
   /**
	 * 
	 */
	private static final long serialVersionUID = 2192054258796819991L;

public DemoPanel(ClnMain _client){

      super();

      client = _client;
      statusLight=0;

      GridBagLayout      gbl      = new GridBagLayout();
      GridBagConstraints gbc = new GridBagConstraints();
      setLayout(gbl);

      modeChoice = new Choice();
      modeChoice.add("Linear Path");
      modeChoice.add("Curved Path");
      modeChoice.select(client.getMouseMode()%2);
      if(client.isNavNetEstablished()){
         autoPilotEnabled=true;
         modeChoice.add("Auto Pilot");
      }else{
         autoPilotEnabled=false;
      }
      modeChoice.addItemListener(
         new ItemListener(){
            public void itemStateChanged(ItemEvent event){
               if(event.getStateChange()==ItemEvent.SELECTED){
                  String s  = (String)(event.getItem());
                  if(client!=null){
                     if(s.equals("Linear Path")){
                        client.setAutoPilot(false);
                        client.setMouseMode(0);
                     }else if(s.equals("Curved Path")){
                        client.setAutoPilot(false);
                        client.setMouseMode(1);
                     }else if(s.equals("Auto Pilot")){
                        client.setAutoPilot(true);
                        // note that mouseMode is unaffected
                     }
                  }
               }
            }
         }
      );

      gbc.anchor=GridBagConstraints.NORTH;
      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=0;
      gbc.gridy=0;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 5, 0, 0);
      gbl.setConstraints(modeChoice, gbc);
      add(modeChoice);

      stopButton = new Button("Stop");
      stopButton.addActionListener(
         new ActionListener(){
            public void actionPerformed(ActionEvent event){
               if(client!=null){
                  client.stopMotion();
               }
            }
         }
      );



      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=0;
      gbc.gridy=1;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 5, 0, 0);
      gbl.setConstraints(stopButton, gbc);
      add(stopButton);

      resetButton = new Button("Reset");
      resetButton.addActionListener(
         new ActionListener(){
            public void actionPerformed(ActionEvent event){
               if(client!=null){
                  client.sendPlacementRequest();
                  RsBodyPainter painter = (RsBodyPainter)(client.body.getPartByName("painter"));
                  if(painter!=null){
                      client.sendPainterErasureRequest(painter);
                  }
               }
            }
         }
      );


      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=0;
      gbc.gridy=2;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 5, 0, 0);
      gbl.setConstraints(resetButton, gbc);
      add(resetButton);

      Label xLabel = new Label("X:");
      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=1;
      gbc.gridy=0;
      gbc.weightx=0;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 20, 0, 0);
      gbl.setConstraints(xLabel, gbc);
      add(xLabel);

      Label yLabel = new Label("Y:");
      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=1;
      gbc.gridy=1;
      gbc.weightx=0;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 20, 0, 0);
      gbl.setConstraints(yLabel, gbc);
      add(yLabel);

      Label aLabel = new Label("Angle:");
      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=1;
      gbc.gridy=2;
      gbc.weightx=0;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 20, 0, 0);
      gbl.setConstraints(aLabel, gbc);
      add(aLabel);


      xField = new TextField(12);
      xField.setEditable(false);
      gbc.fill=GridBagConstraints.NONE;
      gbc.gridx=2;
      gbc.gridy=0;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 0, 0, 0);
      gbl.setConstraints(xField, gbc);
      add(xField);

      yField = new TextField(12);
      yField.setEditable(false);
      gbc.fill=GridBagConstraints.NONE;
      gbc.gridx=2;
      gbc.gridy=1;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 0, 0, 0);
      gbl.setConstraints(yField, gbc);
      add(yField);

      aField = new TextField(12);
      aField.setEditable(false);
      gbc.fill=GridBagConstraints.NONE;
      gbc.gridx=2;
      gbc.gridy=2;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(3, 0, 0, 0);
      gbl.setConstraints(aField, gbc);
      add(aField);


      Label sLabel = new Label("Status:");
      gbc.fill=GridBagConstraints.HORIZONTAL;
      gbc.gridx=1;
      gbc.gridy=3;
      gbc.weightx=0;
      gbc.weighty=1;
      gbc.insets=new Insets(10, 20, 0, 0);
      gbl.setConstraints(sLabel, gbc);
      add(sLabel);

      statusField = new TextField(12);
      statusField.setText("Halted");
      statusField.setEditable(false);
      statusField.setBackground(Color.lightGray);
      gbc.fill=GridBagConstraints.NONE;
      gbc.gridx=2;
      gbc.gridy=3;
      gbc.weightx=1;
      gbc.weighty=1;
      gbc.insets=new Insets(10, 0, 0, 0);
      gbl.setConstraints(statusField, gbc);
      add(statusField);


      // set parameters (must not be done until all elements are created)
      setUnits("Inches");

   }

   public void setUnits(String s){
      if(s.equals("Inches")){
         rsUnits = new RsInches();
      }else if(s.equals("Feet")){
         rsUnits = new RsFeet();
      }else if(s.equals("Meters")){
         rsUnits = new RsMeters();
      }
   }

   public void setPositionOrientation(double x, double y, double orientation){
      if(rsUnits==null){
         xField.setText("");
         yField.setText("");
         aField.setText("");
      }else{
         xField.setText(rsUnits.format(rsUnits.internalToUser(x)));
         yField.setText(rsUnits.format(rsUnits.internalToUser(y)));
         int iOrient = ((int)Math.floor(orientation*180/Math.PI+0.5)+720)%360;
         if(iOrient<10)
           aField.setText("00"+iOrient);
         else if(iOrient<100)
           aField.setText("0"+iOrient);
         else
           aField.setText(""+iOrient);
      }
   }

   public void applyMotionEvent(RsMotionHaltedEvent event){
      setPositionOrientation(event.x, event.y, event.orientation);
      if(event.causeOfHalt==RsMotionHaltedEvent.HALTED_ON_COLLISION){
         setStatusForCollision(true);
      }else{
         setStatusForCollision(false);
      }
      setStatusForMotion(false);
      applyStatus();
   }

   public void applyMotionEvent(RsMotionStartedEvent event){
      setPositionOrientation(event.x, event.y, event.orientation);
      setStatusForMotion(true);
      setStatusForCollision(false);
      applyStatus();
   }

   public void setStatusForMotion(boolean value){
      inMotion=value;
   }

   public void setStatusForSensor(boolean value){
      sensorHot=value;
   }

   public void setStatusForCollision(boolean value){
      inCollision=value;
   }

   public void applyStatus(){
      if(sensorHot){
         if(statusLight!=1){
            statusLight=1;
            statusField.setBackground(Color.orange);
            statusField.setText("Detection");
         }
      }else if(inCollision){
         if(statusLight !=2){
            statusLight=2;
            statusField.setBackground(Color.red);
            statusField.setText("Collision");

         }
      }else if(inMotion ){
         if(statusLight!=3){
            statusLight=3;
            statusField.setBackground(Color.green);
            statusField.setText("In Motion");
         }
      }else{
         if(statusLight!=4){
            statusLight=4;
            statusField.setBackground(Color.lightGray);
            statusField.setText("Halted");
         }
      }
   }

   protected void checkForAutoPilot(){
      if(!autoPilotEnabled && client.isNavNetEstablished()){
         autoPilotEnabled=true;
         modeChoice.add("Auto Pilot");
      }
   }


   protected RsUnits   rsUnits;

   protected Choice    modeChoice;
   protected Button    stopButton;
   protected Button    resetButton;

   protected TextField xField;
   protected TextField yField;
   protected TextField aField;

   protected TextField statusField;

   protected ClnMain   client;

   protected boolean   sensorHot;
   protected boolean   inCollision;
   protected boolean   inMotion;
   protected int       statusLight;

   private boolean     autoPilotEnabled;
}
