/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1.rossum.event;

/*

   RsMotionStartedEvent.java

   The motion-started event is issued when the model initiates a
   motion and is sent to all clients registered for a particular
   robot.

   The motion-started event contains position data for the robot.
   Before using this information, developers should consider the admonition
   on cheating in the documentation for the RsPositionEvent class.
*/



/**
 * An event generated by the simulator when a motion is begun.
 *
 */

public class RsMotionStartedEvent extends RsEvent {

   /**
	 * 
	 */
	private static final long serialVersionUID = -6103608213493449638L;
public RsMotionStartedEvent(
      double  simTime,
      double  linearVelocity,
      double  rotationalVelocity,
      double  duration,
      double  x,
      double  y,
      double  orientation)
   {
      super(EVT_MOTION_STARTED, simTime);
      this.linearVelocity     = linearVelocity;
      this.rotationalVelocity = rotationalVelocity;
      this.duration           = duration;
      this.x                  = x;
      this.y                  = y;
      this.orientation        = orientation;
   }

   public final double linearVelocity;
   public final double rotationalVelocity;
   public final double duration;
   public final double x;
   public final double y;
   public final double orientation;
}




