/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */




/*

The PaintSensorEvent is generated when the status of the sensor changes.
This may include going from a hot-to-cold (detection to no-detection) or
visa versa.

The PaintSensor is assumed to be a single-point, though it may
be depicted by a polygon of larger area to provide a visual
representation of the sensor.

The PaintSensorEvent includes the abosolute position of the
sensor.   These coordinates are intended for diagnostic or human-interface
purposes.  Using these in a client's navigation logic is cheating.

*/



package rp1.rossum.event;



/**
 * An event generated by the simulator when a paint sensor undergoes
 * a change in state.
 *
 */

public class RsPaintSensorEvent extends RsSensorEvent{

   /**
	 * 
	 */
	private static final long serialVersionUID = 615410220677826944L;
public RsPaintSensorEvent(
      double  simTime,
      int     sensorID,
      double  x,
      double  y,
      boolean status,
      int     region)
  {
         super(EVT_PAINT_SENSOR, simTime, sensorID);
         this.x         = x;
         this.y         = y;
         this.status    = status;
         this.region    = region;
   }

   public final double  x, y;
   public final boolean status;
   public final int     region;
}

