/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.clientzero;
import  rp1.rossum.*;
import  rp1.rossum.event.RsMouseClickEventHandler;
import  rp1.rossum.event.RsMouseClickEvent;



public class ClnMouseClickEventHandler implements RsMouseClickEventHandler {

   private ClnMain   client;

   // constructors ----------------------------------------------------
   public ClnMouseClickEventHandler(ClnMain client){
      this.client   = client;
   }


   // methods related to interface -------------------------------------
   public void process(RsMouseClickEvent event){
      client.verbose("Received mouse click event");

      if(client.autoPilot){
        // In auto-pilot mode, the mouse click simply instructs
        // the program to select the closest target.   It does
        // not affect the current progress of the search.
        // This feature was implemented as a testing and debugging aid.
        RsTarget [] a = client.navNet.getTargetArray();
        if(a!=null){
           double    d, dx, dy;
           double    minDistSquared=1.0e+36;
           RsTarget  minTarget=a[0];
           for(int i=0; i<a.length; i++){
              dx = a[i].x - event.x;
              dy = a[i].y - event.y;
              d = dx*dx + dy*dy;
              if(d<minDistSquared){
                 minDistSquared=d;
                 minTarget = a[i];
              }
           }
           client.verbose("Sending target selection request");
           client.sendExclusiveTargetSelectionRequest(minTarget.getName());
        }

        return;
      }

      client.sendHaltRequest();
      client.verbose("Sending position request");
      client.sendPositionRequest();
      client.latestMouseClick=event;
      client.motionPath=null;
   }
}
