
/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.clientzero;

public class ClnPath
{

   public ClnPath(){
      nMove      = 0;
      nMoveAlloc = 0;
      move       = null;
      duration   = 0;
   }

   public void clear(){
      for(int i=0; i<nMove; i++)
         move[i].remark = null;
      nMove = 0;
      duration = 0;
   }


   public void alloc(int k){
      int n = nMove+k;
      if(n>nMoveAlloc){
        int i;
        ClnMove [] newMove;
        n = (n/32+1)*32;
        newMove = new ClnMove[n];
        for(i=0; i<nMoveAlloc; i++)
           newMove[i]=move[i];
        for(i=nMoveAlloc; i<n; i++)
           newMove[i] = new ClnMove();
        nMoveAlloc=n;
        move=newMove;
      }
   }

   public void add(
      double _sLinear,
      double _sAngular,
      double _duration,
      double _x,
      double _y,
      double _orientation){
      alloc(1);
      ClnMove m     = move[nMove++];
      m.sLinear     = _sLinear;
      m.sAngular    = _sAngular;
      m.duration    = _duration;
      m.x           = _x;
      m.y           = _y;
      m.orientation = _orientation;
      m.remark      = null;
      duration     += _duration;
   }


   public void add(ClnMove a){
      alloc(1);
      ClnMove m     = move[nMove++];
      m.sLinear     = a.sLinear;
      m.sAngular    = a.sAngular;
      m.duration    = a.duration;
      m.x           = a.x;
      m.y           = a.y;
      m.orientation = a.orientation;
      m.remark      = a.remark;
      duration     += a.duration;
   }


   public void add(ClnMove a, String remark){
      alloc(1);
      ClnMove m     = move[nMove++];
      m.sLinear     = a.sLinear;
      m.sAngular    = a.sAngular;
      m.duration    = a.duration;
      m.x           = a.x;
      m.y           = a.y;
      m.orientation = a.orientation;
      m.remark      = remark;
      duration     += a.duration;
   }



   public void copy(ClnPath path){
      clear();
      append(path);
   }

   public void append(ClnPath path){
      alloc(path.nMove);
      for(int i=0; i<path.nMove; i++){
         move[nMove].sLinear     = path.move[i].sLinear;
         move[nMove].sAngular    = path.move[i].sAngular;
         move[nMove].duration    = path.move[i].duration;
         move[nMove].x           = path.move[i].x;
         move[nMove].y           = path.move[i].y;
         move[nMove].orientation = path.move[i].orientation;
         move[nMove].remark      = path.move[i].remark;
         nMove++;
      }
      duration += path.duration;
   }





   public void removeLast(int n){
      int i;
      i = nMove-n;
      if(i < 0)
        i = 0;
      for(; i<nMove; i++){
           duration -= move[i].duration;
           move[i].remark=null;
      }
      nMove -= n;
   }

   public void remark(String remark){
     if(nMove>0)
        move[nMove-1].remark=remark;
   }

   public void compact(){
      int k;
      k=1;
      for(int i=1; i<nMove; i++){
         if(move[k-1].sAngular==0 && move[i].sAngular==0){
            move[k-1].sLinear    += move[i].sLinear;
            move[k-1].duration   += move[i].duration;
            move[k-1].x           = move[i].x;
            move[k-1].y           = move[i].y;
            move[k-1].orientation = move[i].orientation;
            move[k-1].remark      = move[i].remark;
         }else{
            if(k<i){
               move[k].sLinear     = move[i].sLinear;
               move[k].sAngular    = move[i].sAngular;
               move[k].duration    = move[i].duration;
               move[k].x           = move[i].x;
               move[k].y           = move[i].y;
               move[k].orientation = move[i].orientation;
               move[k].remark      = move[i].remark;
            }
            k++;
         }
      }
      nMove=k;
   }



   public void computeFinalPosition(double x, double y, double orientation){

      // TO DO:  the following is correct for our point-and-shoot approach
      // (in which only one of either sLinear or sAngular is non-zero,
      // so the robot is either pivoting or moving in a straight line).
      // it will need improvement when we allow curved arch movements.

      ClnMove m;
      for(int i=0; i<nMove; i++){
         m=move[i];
         orientation+=m.sAngular;
         if(m.sLinear!=0.0){
            x+=m.sLinear*Math.cos(orientation);
            y+=m.sLinear*Math.sin(orientation);
         }
      }
      xFinal=x;
      yFinal=y;
      orientationFinal=orientation;
   }


   public  int nMove;
   private int nMoveAlloc;
   public  ClnMove [] move;

   public  double duration;
   public  double xFinal;
   public  double yFinal;
   public  double orientationFinal;

}
