/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */



package rp1demo.demozero;

import java.awt.*;
import java.awt.event.*;

import  rp1.rossum.event.*;
import rp1demo.clientzero.*;

public class DemoFrame extends Frame
{
   /**
	 * 
	 */
	private static final long serialVersionUID = 6545521086458097489L;

public DemoFrame(ClnMain _client){

      super();

      addWindowListener(
         new WindowAdapter(){
             @Override
			public void windowClosing(WindowEvent e){
               dispose();
               System.exit(0);
             }
         }
      );

      client = _client;
      int         width, height;
      width=300;
      height=170;
      setSize(width, height);


      setTitle("Rossum's Playhouse -- Demo Client");
      setBackground(Color.lightGray);


      // build components for inclusion -----------------------
      MenuBar menuBar  = new  MenuBar();
      menuBar.add(createFileMenu());
      menuBar.add(createViewMenu());
      setMenuBar(menuBar);

      demoPanel = new DemoPanel(client);
      add(demoPanel, "North");


      // set parameters (must not be done until all elements are created)
      setUnits("Inches");
   }

   private Menu createFileMenu(){
      Menu     fileMenu = new Menu("File");
      MenuItem exitItem = new MenuItem("Exit");
      fileMenu.add(exitItem);
      exitItem.addActionListener(
         new ActionListener(){
            public void actionPerformed(ActionEvent event){
               dispose();
               System.exit(0);
            }
         }
      );
      return fileMenu;
   }

   private Menu createViewMenu(){
      Menu viewMenu  = new Menu("View");
      Menu unitsMenu = new Menu("Units");
      CheckboxItemListener c = new CheckboxItemListener();

      unitsMenu.add(inchesItem = createUnitsItem("Inches", c));
      unitsMenu.add(feetItem   = createUnitsItem("Feet",   c));
      unitsMenu.add(metersItem = createUnitsItem("Meters", c));
      viewMenu.add(unitsMenu);
      return viewMenu;
   }

   private CheckboxMenuItem createUnitsItem(String s, CheckboxItemListener c){
      CheckboxMenuItem item = new CheckboxMenuItem(s);
      item.setState(false);
      item.addItemListener(c);
      return item;
   }

   private void radioMenuSelectItem(MenuItem item){
      CheckboxMenuItem testItem;
      Menu             parent=(Menu)(item.getParent());
      int              nItem=parent.getItemCount();

      for(int i=0; i<nItem; i++){
         testItem=(CheckboxMenuItem)(parent.getItem(i));
         testItem.setState(item==testItem);
      }
   }

   public void setUnits(String s){
      demoPanel.setUnits(s);
      if(s.equals("Inches")){
         inchesItem.setState(true);
         feetItem.setState(  false);
         metersItem.setState(false);
      }else if(s.equals("Feet")){
         inchesItem.setState(false);
         feetItem.setState(  true);
         metersItem.setState(false);
      }else if(s.equals("Meters")){
         inchesItem.setState(false);
         feetItem.setState(  false);
         metersItem.setState(true);
      }
   }

   class CheckboxItemListener implements ItemListener {
      public void itemStateChanged(ItemEvent event){
         radioMenuSelectItem((MenuItem)(event.getItemSelectable()));
         String s = (String)(event.getItem());
         demoPanel.setUnits(s);
      }
   }

   public void applyMotionEvent(RsMotionHaltedEvent event){
      demoPanel.applyMotionEvent(event);
   }

   public void applyMotionEvent(RsMotionStartedEvent event){
      demoPanel.applyMotionEvent(event);
   }

   public void setPositionOrientation(double x, double y, double orientation){
      demoPanel.setPositionOrientation(x, y, orientation);
   }

   public void setStatusForMotion(boolean value){
      demoPanel.setStatusForMotion(value);
   }

   public void setStatusForSensor(boolean value){
      demoPanel.setStatusForSensor(value);
   }

   public void setStatusForCollision(boolean value){
      demoPanel.setStatusForCollision(value);
   }

   public void applyStatus(){
      demoPanel.applyStatus();
   }


   protected DemoPanel        demoPanel;
   protected CheckboxMenuItem inchesItem;
   protected CheckboxMenuItem feetItem;
   protected CheckboxMenuItem metersItem;

   protected ClnMain          client;
}


