/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a drunk/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.drunk;
import rp1.rossum.event.*;



public class DrunkMotionHaltedEventHandler implements RsMotionHaltedEventHandler {

   private DrunkMain   drunk;
   private double      firstTime;
   private double      firstSimTime;
   private int         nMoveCompleted;
   private int         nMoveForTest;
   private double      duration;     // accumulated duration of movements
   private boolean     verbosity;

   public DrunkMotionHaltedEventHandler(DrunkMain drunk, int nMoveForTest){
      this.drunk        = drunk;
      this.nMoveForTest = nMoveForTest;
      nMoveCompleted    = 0;
      duration          = 0;
      verbosity         = drunk.getVerbosity();
   }

   public void process(RsMotionHaltedEvent event){

      if(verbosity)
         drunk.verbose("motion halted: "+event.whyHalted());

      if(nMoveCompleted==0){
          firstTime=System.currentTimeMillis()/1000.0;
          firstSimTime=event.simTime;
      }else if((nMoveCompleted%100)==0){
         double deltaTime= System.currentTimeMillis()/1000.0-firstTime;
         drunk.log("# "+nMoveCompleted+", "+deltaTime+", "
            +(event.simTime-firstSimTime)+", "+duration);
         if(nMoveCompleted==nMoveForTest){
            drunk.log("Test Completed.  Shutting down");
            System.exit(0);
         }
      }
      nMoveCompleted++;
      duration+=event.duration;
      drunk.nextMove();
   }
}
