/*  -------------------------------------------------------------

    Rossum's Playhouse  --  a client/server based robot simulator
    Rossum's Playhouse is also known under the name "RP1".
    Copyright (C) 1999  G.W. Lucas

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

----------------------------------------------------------------- */


package rp1demo.linetracker;
import  rp1.rossum.*;
import java.awt.Color;

public class LtBody {

   public static RsBody  build(){
       RsBody body = new RsBody("LineTracker");

       RsDifferentialSteering wheelSystem = new RsDifferentialSteering(
         m(3.0),   // wheel track width
         m(1.0)    // drive wheel radius
      );

      wheelSystem.addDefaultWheels(m(1.0), m(0.5));
      wheelSystem.setFillColor(Color.darkGray);
      wheelSystem.setLineColor(Color.darkGray);


      // note:  that which is added first is also drawn first.

      double [] dFrontFender = {
         1.250,  1.875,
         1.500,  1.875,
         1.500, -1.875,
         1.250, -1.875
       };

      RsBodyShape frontFender = new RsBodyShape(m(dFrontFender), dFrontFender.length/2);
      frontFender.setName("FrontFender");
      frontFender.setFillColor(Color.yellow);
      frontFender.setLineColor(Color.darkGray);
      body.addPart(frontFender);

      double [] dRearFender = {
        -1.250,   1.875,
        -1.500,   1.875,
        -1.500,  -1.875,
        -1.250,  -1.875
       };

      RsBodyShape rearFender = new RsBodyShape(m(dRearFender), dRearFender.length/2);
      rearFender.setName("RearFender");
      rearFender.setFillColor(Color.yellow);
      rearFender.setLineColor(Color.darkGray);
      body.addPart(rearFender);




      double [] dChassis = {
        -2.0,    1.5,
         2.0,    1.5,
         2.0,    0.375,
         2.250,  0.375,
         2.250, -0.375,
         2.0,   -0.375,
         2.0,   -1.5,
        -2.0,   -1.5
      };


      RsBodyShape chassis = new RsBodyShape(m(dChassis), dChassis.length/2);
      chassis.setName("Chassis");
      chassis.setFillColor(Color.yellow);
      chassis.setLineColor(Color.darkGray);
      body.addPart(chassis);



      double [] dLeftSensor = {
         1.250,    1.0,
         1.250,    0.375,
         2.250,    0.375,
         2.250,    0.625,
         2.0,      0.625,
         2.0,      1.0,
         1.250,    1.0
      };

      RsBodyPaintSensor leftSensor =
         new RsBodyPaintSensor(
             m(dLeftSensor), dLeftSensor.length/2, m(2.25), m(0.5));
      leftSensor.setName("Left Paint Sensor");
      leftSensor.setFillColor(Color.lightGray);
      leftSensor.setLineColor(Color.darkGray);
      leftSensor.setHotFillColor(Color.orange);
      leftSensor.setHotLineColor(Color.darkGray);
      leftSensor.setRegionSensitivity(1);
      body.addPart(leftSensor);

      double [] dRightSensor = {
         1.250,   -1.0,
         1.250,   -0.375,
         2.250,   -0.375,
         2.250,   -0.625,
         2.0,     -0.625,
         2.0,     -1.0,
         1.250,   -1.0


      };

      RsBodyPaintSensor rightSensor =
         new RsBodyPaintSensor(
             m(dRightSensor), dRightSensor.length/2, m(2.25), m(-0.5));
      rightSensor.setName("Right Paint Sensor");
      rightSensor.setFillColor(Color.lightGray);
      rightSensor.setLineColor(Color.darkGray);
      rightSensor.setHotFillColor(Color.orange);
      rightSensor.setHotLineColor(Color.darkGray);
      rightSensor.setRegionSensitivity(1);
      body.addPart(rightSensor);


      body.addPart(wheelSystem);
      return body;
   }

   private static double m(double inches){
      return inches*0.0254;
   }

   private static double [] m (double []inches){
      double [] d =new double[inches.length];
      for(int i=0; i<inches.length; i++)
         d[i] = inches[i]*0.0254;
      return d;
   }

}

